import glob
import os.path as path

def load_recursive(path_, encoding="cp932"):
    oto_json = {}
    for oto_ini in glob.glob(path.join(path_, "**/oto.ini"), recursive=True):
        oto_json.update(load(oto_ini, root=path_, encoding=encoding))
    return oto_json

def load(path_, root=None, encoding="cp932"):
    oto_json = {}
    with open(path_, "r", encoding=encoding) as f:
        for line in f.readlines():
            line = line.strip()
            [source, params] = line.split("=")
            [name, left_margin, fixed, right_margin, prepronounced, overlapping] = params.split(",")
            oto_dir = path.dirname(path_) if root == None else path.relpath(path.dirname(path_), root)
            source = path.join(oto_dir, source)
            oto_json[name] = {
                    "source": source,
                    "leftMargin": left_margin,
                    "rightMargin": right_margin,
                    "fixed": fixed,
                    "prepronounced": prepronounced,
                    "overlapping": overlapping
                    }
    return oto_json

if __name__ == "__main__":
    import json

    print(json.dumps(load_recursive("."), indent=2, ensure_ascii=False))



def load(path_, encoding="cp932"):
    prefix_map = {}
    with open(path_, encoding=encoding) as f:
        for line in f.readlines():
            prefix_map.update((line.strip().split(),))
    return prefix_map



import struct

class Type:
    def __init__(self, format_id, sample_width, key_frequency, nsamples, frq_samples, amp_samples):
        self.format_id = format_id
        self.sample_width = sample_width
        self.key_frequency = key_frequency
        self.nsamples = nsamples
        self.frq_samples = frq_samples
        self.amp_samples = amp_samples


_fmt_hdr = struct.Struct('<8sid16si')
_fmt_smp = struct.Struct('<dd')

def load(path_):
    with open(path_, "rb") as f:
        buffer_ = f.read()

    [format_id, sample_width, key_frequency, _, nsamples] = _fmt_hdr.unpack_from(buffer_)

    frq_samples = []
    amp_samples = []

    for (frq, amp) in _fmt_smp.iter_unpack(buffer_[_fmt_hdr.size:]):
        frq_samples.append(frq)
        amp_samples.append(amp)

    assert len(frq_samples) == nsamples
    assert len(amp_samples) == nsamples

    return Type(
            format_id = format_id,
            sample_width = sample_width,
            key_frequency = key_frequency,
            nsamples = nsamples,
            frq_samples = frq_samples,
            amp_samples = amp_samples
            )



from setuptools import setup
from setuptools import find_packages

setup(
        name="strcuta",
        version="0.0.1",
        url="https://github.com/takagiy/strcutau",
        description="Load UTAU voice banks into the Python data structure.",
        author="takagiy",
        author_email="takagiy.4dev@gmail.com",
        license="MIT",
        packages=find_packages(),
        include_package_data=False,
        install_requires=[])
